@@ -3,11 +3,12 @@ import sqlite3
 
 class EasyDB:
     def __init__(self, filename, schema = None, **kwargs):
-        if os.path.exists(filename) or schema:
-            self.connection = sqlite3.connect(filename)
-        elif not schema:
+        exists = os.path.exists(filename)
+        if not exists and not schema:
             raise Exception, "The specified database file does not exist, and you haven't provided a schema"
-        else:
+    
+        self.connection = sqlite3.connect(filename)
+        if not exists:
             for table_name, fields in schema.items():
                 query = "CREATE TABLE %s (%s)" % (table_name, ", ".join(fields))
                 self.query(query)
